@@ -4,10 +4,9 @@ from .. import dispatch as dispatch_original
 from ..types import Number, NPNumeric
 
 
-# All methods here should have precedence, because NumPy forms the base of
-# everything.
+# All methods here should have precedence, because NumPy forms the base of everything.
 def dispatch(*args, **kw_args):
-    kw_args['precedence'] = 1
+    kw_args["precedence"] = 1
     return dispatch_original(*args, **kw_args)
 
 
